==> rclone-v1.73.0.tar.gz: rclone-v1.73.0/docs/content/sponsor.md <==
---
title: "Sponsor"
description: "Sponsor the rclone project."
type: page
aliases:
- donate
---

# {{< icon "fa fa-heart heart" >}} Sponsor the rclone project

Thank you to our sponsors:

<!-- markdownlint-capture -->
<!-- markdownlint-disable line-length no-bare-urls -->

{{< sponsor src="/img/logos/rabata.svg" width="300" height="200" title="Visit our sponsor Rabata.io" link="https://rabata.io/?utm_source=banner&utm_medium=rclone&utm_content=general">}}
{{< sponsor src="/img/logos/idrive_e2.svg" width="300" height="200" title="Visit our sponsor IDrive e2" link="https://www.idrive.com/e2/?refer=rclone">}}
{{< sponsor src="/img/logos/filescom-enterprise-grade-workflows.png" width="300" height="200" title="Start Your Free Trial Today" link="https://files.com/?utm_source=rclone&utm_medium=referral&utm_campaign=banner&utm_term=rclone">}}
{{< sponsor src="/img/logos/mega-s4.svg" width="300" height="200" title="MEGA S4: New S3 compatible object storage. High scale. Low cost. Free egress." link="https://mega.io/objectstorage?utm_source=rclone&utm_medium=referral&utm_campaign=rclone-mega-s4&mct=rclonepromo">}}
{{< sponsor src="/img/logos/sia.svg" width="200" height="200" title="Visit our sponsor sia" link="https://sia.tech">}}
{{< sponsor src="/img/logos/route4me.svg" width="400" height="200" title="Visit our sponsor Route4Me" link="https://route4me.com/">}}
{{< sponsor src="/img/logos/rcloneview-banner.svg" width="300" height="200" title="Visit our sponsor RcloneView" link="https://rcloneview.com/">}}
{{< sponsor src="/img/logos/rcloneui.svg" width="300" height="200" title="Visit our sponsor RcloneUI" link="https://github.com/rclone-ui/rclone-ui">}}
{{< sponsor src="/img/logos/shade.svg" width="300" height="200" title="Visit our sponsor Shade" link="https://shade.inc">}}
{{< sponsor src="/img/logos/filelu-rclone.svg" width="300" height="200" title="Visit our sponsor FileLu" link="https://filelu.com/">}}
{{< sponsor src="/img/logos/torbox.png" width="200" height="200" title="Visit our sponsor TORBOX" link="https://www.torbox.app/">}}
{{< sponsor src="/img/logos/spectra-logic.svg" width="300" height="200" title="Visit our sponsor Spectra Logic" link="https://spectralogic.com/">}}
{{< sponsor src="/img/logos/servercore.svg" width="300" height="200" title="Visit our sponsor servercore" link="https://servercore.com/services/object-storage/?utm_source=rclone.org&utm_medium=referral&utm_campaign=cloud-s3_rclone_231025_paid">}}

<!-- markdownlint-restore -->

Rclone is a free open-source project with thousands of contributions
from volunteers all round the world and I would like to thank all of
you for donating your time to the project.

However, maintaining rclone is a lot of work - it is **my full time
job**. Nothing stands still in the world of cloud storage. Rclone
needs constant attention adapting to changes by cloud providers,
adding new providers, adding new features, keeping the integration
tests working, fixing bugs and many more things!

I love doing the work and I'd like to keep doing it - your support
helps make rclone possible.

Thank you :-)

{{< nick >}}

## Business users

If your business or your customers rely on rclone then it would make
sense to sponsor rclone to ensure that the open source project you
need stays healthy and well maintained.

Sponsorship can include support contracts, advertising deals and
consultancy.

Please see our business site [rclone.com](https://rclone.com) for
details.

{{< bizbutton >}}

## Personal users

If you are a personal user and you would like to support the project
with sponsorship as a way of saying thank you that would be most
appreciated. {{< icon "fa fa-heart heart" >}}

{{< monthly_donations >}}

If you don't want to contribute monthly then of course we'd love a one
off donation.

{{< one_off_donations >}}

==> rclone-1.73.1.tar.gz: rclone-1.73.1/docs/content/sponsor.md <==
---
title: "Sponsor"
description: "Sponsor the rclone project."
type: page
aliases:
- donate
---

# {{< icon "fa fa-heart heart" >}} Sponsor the rclone project

Thank you to our sponsors:

<!-- markdownlint-capture -->
<!-- markdownlint-disable line-length no-bare-urls -->

{{< sponsor src="/img/logos/rabata.svg" width="300" height="200" title="Visit our sponsor Rabata.io" link="https://rabata.io/?utm_source=banner&utm_medium=rclone&utm_content=general">}}
{{< sponsor src="/img/logos/idrive_e2.svg" width="300" height="200" title="Visit our sponsor IDrive e2" link="https://www.idrive.com/e2/?refer=rclone">}}
{{< sponsor src="/img/logos/filescom-enterprise-grade-workflows.png" width="300" height="200" title="Start Your Free Trial Today" link="https://files.com/?utm_source=rclone&utm_medium=referral&utm_campaign=banner&utm_term=rclone">}}
{{< sponsor src="/img/logos/internxt.jpg" width="300" height="200" title="Visit rclone's sponsor Internxt" link="https://internxt.com/specialoffer/rclone">}}
{{< sponsor src="/img/logos/mega-s4.svg" width="300" height="200" title="MEGA S4: New S3 compatible object storage. High scale. Low cost. Free egress." link="https://mega.io/objectstorage?utm_source=rclone&utm_medium=referral&utm_campaign=rclone-mega-s4&mct=rclonepromo">}}
{{< sponsor src="/img/logos/sia.svg" width="200" height="200" title="Visit our sponsor sia" link="https://sia.tech">}}
{{< sponsor src="/img/logos/route4me.svg" width="400" height="200" title="Visit our sponsor Route4Me" link="https://route4me.com/">}}
{{< sponsor src="/img/logos/rcloneview.svg" width="300" height="200" title="Visit our sponsor RcloneView" link="https://rcloneview.com/">}}
{{< sponsor src="/img/logos/rcloneui.svg" width="300" height="200" title="Visit our sponsor RcloneUI" link="https://github.com/rclone-ui/rclone-ui">}}
{{< sponsor src="/img/logos/shade.svg" width="300" height="200" title="Visit our sponsor Shade" link="https://shade.inc">}}
{{< sponsor src="/img/logos/filelu-rclone.svg" width="300" height="200" title="Visit our sponsor FileLu" link="https://filelu.com/">}}
{{< sponsor src="/img/logos/torbox.png" width="200" height="200" title="Visit our sponsor TORBOX" link="https://www.torbox.app/">}}
{{< sponsor src="/img/logos/spectra-logic.svg" width="300" height="200" title="Visit our sponsor Spectra Logic" link="https://spectralogic.com/">}}
{{< sponsor src="/img/logos/servercore.svg" width="300" height="200" title="Visit our sponsor servercore" link="https://servercore.com/services/object-storage/?utm_source=rclone.org&utm_medium=referral&utm_campaign=cloud-s3_rclone_231025_paid">}}
{{< sponsor src="/img/logos/exchangerate-api.png" width="300" height="200" title="Visit our sponsor ExchangeRate-API" link="https://www.exchangerate-api.com/">}}

<!-- markdownlint-restore -->

Rclone is a free open-source project with thousands of contributions
from volunteers all round the world and I would like to thank all of
you for donating your time to the project.

However, maintaining rclone is a lot of work - it is **my full time
job**. Nothing stands still in the world of cloud storage. Rclone
needs constant attention adapting to changes by cloud providers,
adding new providers, adding new features, keeping the integration
tests working, fixing bugs and many more things!

I love doing the work and I'd like to keep doing it - your support
helps make rclone possible.

Thank you :-)

{{< nick >}}

## Business users

If your business or your customers rely on rclone then it would make
sense to sponsor rclone to ensure that the open source project you
need stays healthy and well maintained.

Sponsorship can include support contracts, advertising deals and
consultancy.

Please see our business site [rclone.com](https://rclone.com) for
details.

{{< bizbutton >}}

## Personal users

If you are a personal user and you would like to support the project
with sponsorship as a way of saying thank you that would be most
appreciated. {{< icon "fa fa-heart heart" >}}

{{< monthly_donations >}}

If you don't want to contribute monthly then of course we'd love a one
off donation.

{{< one_off_donations >}}
